summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmheightfieldedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmheightfieldedit.h')
-rw-r--r--kpovmodeler/pmheightfieldedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmheightfieldedit.h b/kpovmodeler/pmheightfieldedit.h
index 2b97b03a..a04e21b3 100644
--- a/kpovmodeler/pmheightfieldedit.h
+++ b/kpovmodeler/pmheightfieldedit.h
@@ -43,9 +43,9 @@ class PMHeightFieldEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMHeightFieldEdit with tqparent and name
*/
- PMHeightFieldEdit( TQWidget* tqparent, const char* name = 0 );
+ PMHeightFieldEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -43,9 +43,9 @@ class PMHeightFieldEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMHeightFieldEdit with tqparent and name
+ * Creates a PMHeightFieldEdit with parent and name
*/